<?php
// Own namespace
namespace Org\Mxchange\CoreFramework\Auth;

// Import framework stuff
use Org\Mxchange\CoreFramework\Generic\FrameworkInterface;
use Org\Mxchange\CoreFramework\Request\Requestable;
use Org\Mxchange\CoreFramework\Response\Responseable;

/**
 * An interface for user login classes
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface LoginableUser extends FrameworkInterface {
	/**
	 * Logins the user with the given request containing the credential. The
	 * result of the login can be thrown by exception or, if prefered stored
	 * in a boolean attribute which is then readable by a matching getter.
	 *
	 * @param	$requestInstance	An instance of a Requestable class
	 * @param	$responseInstance	An instance of a Responseable class
	 * @return	void
	 */
	function doLogin (Requestable $requestInstance, Responseable $responseInstance);

	/**
	 * Check if the implementation is correct. Only the request instance is
	 * needed as no redirect is done here.
	 *
	 * @param	$requestInstance	An instance of a Requestable class
	 * @return
	 */
	function testLogin (Requestable $requestInstance);

}
